<?php

/**
 * This is the model class for table "hlp_Topic".
 *
 * The followings are the available columns in table 'hlp_Topic':
 * @property integer $TopicId
 * @property integer $ParentId
 * @property integer $SectionId
 * @property integer $Order
 * @property string $Created
 * @property string $Modified
 *
 * The followings are the available model relations:
 * @property Topic $parent
 * @property Topic[] $Topics
 * @property Section $section
 * @property TopicText[] $TopicTexts
 */
class Topic extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'hlp_Topic';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('SectionId, Created', 'required'),
			array('ParentId, SectionId, Order', 'numerical', 'integerOnly'=>true),
			array('Modified', 'safe'),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('TopicId, ParentId, SectionId, Order, Created, Modified', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'parent' => array(self::BELONGS_TO, 'Topic', 'ParentId'),
			'Topics' => array(self::HAS_MANY, 'Topic', 'ParentId'),
			'section' => array(self::BELONGS_TO, 'Section', 'SectionId'),
			'TopicTexts' => array(self::HAS_MANY, 'TopicText', 'TopicId'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'TopicId' => 'Topic',
			'ParentId' => 'Parent',
			'SectionId' => 'Section',
			'Order' => 'Order',
			'Created' => 'Created',
			'Modified' => 'Modified',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('TopicId',$this->TopicId);
		$criteria->compare('ParentId',$this->ParentId);
		$criteria->compare('SectionId',$this->SectionId);
		$criteria->compare('Order',$this->Order);
		$criteria->compare('Created',$this->Created,true);
		$criteria->compare('Modified',$this->Modified,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Topic the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
