<?php

/**
 * This is the model class for table "hlp_TopicText".
 *
 * The followings are the available columns in table 'hlp_TopicText':
 * @property integer $TopicTextId
 * @property integer $TopicId
 * @property string $Title
 * @property string $Body
 * @property string $Created
 * @property string $Modified
 * @property string $LCID
 *
 * The followings are the available model relations:
 * @property Language $lC
 * @property Topic $topic
 */
class TopicText extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'hlp_TopicText';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('TopicId, Title, Created, LCID', 'required'),
			array('TopicId', 'numerical', 'integerOnly'=>true),
			array('Title', 'length', 'max'=>255),
			array('LCID', 'length', 'max'=>5),
			array('Body, Modified', 'safe'),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('TopicTextId, TopicId, Title, Body, Created, Modified, LCID', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'lC' => array(self::BELONGS_TO, 'Language', 'LCID'),
			'topic' => array(self::BELONGS_TO, 'Topic', 'TopicId'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'TopicTextId' => 'Topic Text',
			'TopicId' => 'Topic',
			'Title' => 'Title',
			'Body' => 'Body',
			'Created' => 'Created',
			'Modified' => 'Modified',
			'LCID' => 'Lcid',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('TopicTextId',$this->TopicTextId);
		$criteria->compare('TopicId',$this->TopicId);
		$criteria->compare('Title',$this->Title,true);
		$criteria->compare('Body',$this->Body,true);
		$criteria->compare('Created',$this->Created,true);
		$criteria->compare('Modified',$this->Modified,true);
		$criteria->compare('LCID',$this->LCID,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return TopicText the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
