<?php
/**
 * BootstrapClassFilter class file.
 * @author  Digital Mesh <info@digitalmesh.com>
 * @copyright Copyright &copy; Digital Mesh 2013-
 * @license http://www.opensource.org/licenses/bsd-license.php New BSD License
 * @package HelpSystem
 */

class BootstrapClassFilter extends CApplicationComponent{
	public $bootstrap2Class = array();
	public $bootstrap3Class = array();
	public function __construct(){
		$this->setBootstrap2Class();
		$this->setBootstrap3Class();
	}
	
	/**
	 * To set Bootstrap2 class
	 */
	private function setBootstrap2Class(){
		$this->bootstrap2Class['topicList'] = array(
				'topic-filter'=>'span11',
				'span3pullleft'=>'span3 pull-left',
				'formControl'=>'',
				'span3pullrighttextright'=>'span3 pull-right text-right',
				'btnBtnSuccessBtnMini'=>'btn btn-success btn-mini',
				'span12Mtop20'=>'span11 Mtop20',
				'btnBtnPrimaryBtnMini'=>'btn btn-primary btn-mini',
				'btnBtnDangerBtnMini'=>'btn btn-danger btn-mini',
				'paginationDiv'=>'span12 pagination pagination-mini text-right',
				'paginationUl'=>'',
		);
		$this->bootstrap2Class['topicAdd'] = array(
				'span12Mtop20'=>'span12 Mtop20',
				'span3'=>'span3',
				'span6'=>'span6 Mtop20',
				'span3Mtop4'=>'span3 Mtop4',
				'formControl'=>'',
				'btnBtnPrimaryBtnMini'=>'btn btn-primary btn-mini',
				'textError'=>'text-error',
				'marginLabel'=>'',
				
		);
		$this->bootstrap2Class['topicOrder'] = array(
				'span12Mtop20'=>'span11 Mtop20',
				'span12'=>'span11',
				'span12A'=>'span11',
				'formControl'=>'',
				'span12B'=>'span11',
		);
		$this->bootstrap2Class['section'] = array(
				'span11Mtop20'=>'span11 Mtop20',
				'span2'=>'span2',
				'span3'=>'span3',
				'formControl'=>'',
				'span2Mtop4'=>'span2 Mtop4',
				'btnBtnPrimaryBtnMini'=>'btn btn-primary btn-mini',
				'btnBtnDangerBtnMini'=>'btn btn-danger btn-mini',
				'span5'=>'span5 text-right',
				'textError'=>'text-error'
		);
	}
	
	/**
	 * To set Bootstrap3 class
	 */
	private function setBootstrap3Class(){
		$this->bootstrap3Class['topicList'] = array(
				'topic-filter'=>'col-md-12 Mtop20',
				'span3pullleft'=>'col-md-6',
				'formControl'=>'form-control',
				'span3pullrighttextright'=>'col-md-3 text-right',
				'btnBtnSuccessBtnMini'=>'btn btn-success btn-sm',
				'span12Mtop20'=>'col-md-12 Mtop20',
				'btnBtnPrimaryBtnMini'=>'btn btn-primary btn-sm',
				'btnBtnDangerBtnMini'=>'btn btn-danger btn-sm',
				'paginationDiv'=>'text-right',
				'paginationUl'=>'pagination pagination-sm',
		);
		$this->bootstrap3Class['topicAdd'] = array(
				'span12Mtop20'=>'col-md-12 Mtop20',
				'span3'=>'col-md-3',
				'span6'=>'col-md-6',
				'span3Mtop4'=>'col-md-3 Mtop4',
				'formControl'=>'form-control',
				'btnBtnPrimaryBtnMini'=>'btn btn-primary btn-sm',
				'textError'=>'text-danger',
				'marginLabel'=>'Mtop20'
		);
		$this->bootstrap3Class['topicOrder'] = array(
				'span12Mtop20'=>'col-md-12 Mtop20',
				'span12'=>'col-md-12',
				'span12A'=>'col-md-4',
				'formControl'=>'form-control',
				'span12B'=>'col-md-12 Mtop20',
		);
		$this->bootstrap3Class['section'] = array(
				'span11Mtop20'=>'col-md-11 Mtop20',
				'span2'=>'col-md-3',
				'span3'=>'col-md-6',
				'span5'=>'col-md-3',
				'formControl'=>'form-control',
				'btnBtnPrimaryBtnMini'=>'btn btn-primary btn-sm',
				'btnBtnDangerBtnMini'=>'btn btn-danger btn-sm',
				'textError'=>'text-danger'
		);
	}
	
	/**
	 * To determine the BootstrapClass to be used by checking the version. 
	 * @param  string $page
	 * @param string $key
	 * @throws CHttpException
	 */
	public function getBootstrapClass($page,$key){
		switch ($this->getBootstrapVersion()){
			case '2':
				return $this->getBootsrap2Class($page, $key);
				break;
			case '3':
				return $this->getBootsrap3Class($page, $key);
				break;
			default:
				Yii::log("Invalid version number $this->getBootstrapVersion() is given",'error');
				throw new CHttpException("Bootstrap version number is not correct");
				break;	
		}
	}
	
	/**
	 * To get Bootstrap2Class of a particular $page and $key 
	 * @param string $page
	 * @param string $key
	 * @throws CHttpException
	 */
	private function getBootsrap2Class($page,$key){
		if(isset($this->bootstrap2Class[$page])){
			if(isset($this->bootstrap2Class[$page][$key])){
				return $this->bootstrap2Class[$page][$key];
			}else{
				
				Yii::log("Invalid class name $key is given",'error');
				throw new CHttpException("Class name is not correct");
			}
		}else{
			Yii::log("Invalid page $page is given",'error');
			throw new CHttpException("Page identifier is not correct");
		}
	}
	

	/**
	 * To get Bootstrap3Class of a particular $page and $key
	 * @param string $page
	 * @param string $key
	 * @throws CHttpException
	 */
	private function getBootsrap3Class($page,$key){
		if(isset($this->bootstrap3Class[$page])){
			if(isset($this->bootstrap3Class[$page][$key])){
				return $this->bootstrap3Class[$page][$key];
			}else{
				Yii::log("Invalid class name $key is given",'error');
				throw new CHttpException("Class name is not correct");
			}
		}else{
			Yii::log("Invalid page $page is given",'error');
			throw new CHttpException("Page identifier is not correct");
		}
	}
	
	/**
	 * To get Bootstrap Version.
	 * @return $version integer
	 */
	public function getBootstrapVersion(){
		$version = Yii::app()->getModule('helpSystem')->bootstrapVersion;
		return $version;
	}
}